[![Build](https://github.com/Chase-Mateusiak/cse587Autils/actions/workflows/python-package.yml/badge.svg)](https://github.com/Chase-Mateusiak/cse587Autils/actions/workflows/python-package.yml)

# Introduction

This package stores objects, functions and at some point possibly data for
Michael Brent's CSE 587A: Algorithms for Computational Biology at Washington
University.  

[See the documentation here](https://cse587a.github.io/cse587Autils/)

# Installation

## Typical User

This is on PyPI and may be installed with pip:

```bash
pip install cse587Autils
```

## Cutting edge version

It is possible that the `dev` branch is ahead of `main` and the `pypi` version.
However, `dev` is not necessarily as stable. Install the `dev` version at your
own risk:

```bash
pip install https://github.com/Chase-Mateusiak/cse587Autils.git@dev
```

# Developers

If you want to participate in improving this repository, then fork the repo
into your own profile. Issue pull requests against `dev`.  

## codespace

A development container is configured such that after you fork the repo, you
can launch a codespace with a pre-configured environment and start coding
right away. Changes you make will be pushed to your fork, and from there you 
can issue pull requests against this repo.
